<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet exclude-result-prefixes="tdl ddb mc cm" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
  xmlns:tdl="http://rep.oio.dk/sundcom.dk/medcom.dk/xml/schemas/2007/07/01/TDL"
  xmlns:xdis="http://rep.oio.dk/sundcom.dk/medcom.dk/xml/schemas/2005/08/07/" 
  xmlns:ddb="http://rep.oio.dk/sundcom.dk/medcom.dk/xml/schemas/2007/07/01/" 
  xmlns:mc="http://www.medcom.dk/ddb/dataowner/mc" xmlns:cm="http://www.medcom.dk/ddb/dataowner/common">

  <xsl:param name="SenderEAN" select="'SenderEAN'"/>
  <xsl:param name="ReceiverEAN" select="'ReceiverEAN'"/>
  <xsl:param name="EnvelopeIdentifier" select="'EnvelopeId'"/>
  <xsl:variable name="identifier" select="/tdl:TheDynamicLetter/tdl:Logistic/tdl:Identifier"/>
  <xsl:variable name="Sender" select="/tdl:TheDynamicLetter/tdl:Roles/tdl:Sender"/>
  <xsl:variable name="ambctrl" select="count(/tdl:TheDynamicLetter/tdl:Contents/mc:HospitalAmbulatoryControl/mc:HospitalAmbulatoryControlYes) > 0"/>
  <xsl:variable name="specialrehab" select="/tdl:TheDynamicLetter/tdl:Contents/mc:ExerciseType/mc:SpecialRehabilitationExercise"/>

  <xsl:template match="/tdl:TheDynamicLetter">
    <xdis:Emessage>
      <xdis:Envelope>
        <xdis:Sent>
          <xsl:variable name="datetime">
            <xsl:choose>
              <xsl:when test="./tdl:Logistic/tdl:SentDateTime">
                <xsl:value-of select="string(tdl:Logistic/tdl:SentDateTime)"/>
              </xsl:when>
              <xsl:otherwise>
                <xsl:value-of select="'2007-01-01T00:01:00'"/>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:variable>
          <xdis:Date>
            <xsl:value-of select="substring-before($datetime,'T')"/>
          </xdis:Date>
          <xdis:Time>
            <xsl:value-of select="substring(substring-after($datetime,'T'), 0, 6)"/>
          </xdis:Time>
        </xdis:Sent>
        <xdis:Identifier>
          <xsl:call-template name="cutTo14">
            <xsl:with-param name="id" select="$EnvelopeIdentifier"/>
          </xsl:call-template>
        </xdis:Identifier>
        <xdis:AcknowledgementCode>pluspositivkvitt</xdis:AcknowledgementCode>
      </xdis:Envelope>
      <xdis:ClinicalEmail>
        <xdis:Letter>
          <xdis:Identifier>
            <xsl:call-template name="cutTo14">
              <xsl:with-param name="id" select="$identifier"/>
            </xsl:call-template>
          </xdis:Identifier>
          <xdis:VersionCode>XD9133L</xdis:VersionCode>
          <xdis:StatisticalCode>XDIS91</xdis:StatisticalCode>
          <xdis:Authorisation>
            <xsl:variable name="datetime" select="./tdl:Roles/tdl:Sender/tdl:Authorisation/tdl:DateTime"/>
            <xdis:Date>
              <xsl:value-of select="substring-before($datetime, 'T')"/>
            </xdis:Date>
            <xdis:Time>
              <xsl:value-of select="substring(substring-after($datetime, 'T'),1,5)"/>
            </xdis:Time>
          </xdis:Authorisation>
          <xdis:TypeCode>XDIS91</xdis:TypeCode>
          <xdis:StatusCode>nytbrev</xdis:StatusCode>
        </xdis:Letter>
        <xdis:Sender>          
          <xsl:apply-templates  select="tdl:Roles/tdl:Sender/tdl:*"/>
        </xdis:Sender>
        <xdis:Receiver>
          <xsl:apply-templates  select="tdl:Roles/tdl:Receiver/tdl:*"/>
        </xdis:Receiver>
        <xdis:Patient>
          <xsl:variable name="Patient" select="./tdl:Roles/tdl:Person"/>
          <xsl:choose>
            <xsl:when test="not($Patient/tdl:IsAlternativeIdentifier=0)">
              <xdis:AlternativeIdentifier>
                <xsl:value-of select="$Patient/tdl:PersonCivilRegistrationIdentifier"/>
              </xdis:AlternativeIdentifier>
            </xsl:when>
            <xsl:otherwise>
              <xdis:CivilRegistrationNumber>
                <xsl:value-of select="$Patient/tdl:PersonCivilRegistrationIdentifier"/>
              </xdis:CivilRegistrationNumber>
            </xsl:otherwise>
          </xsl:choose>
          <xdis:PersonSurnameName>
            <xsl:value-of select="$Patient/tdl:PersonMiddleName"/>
            <xsl:value-of select="$Patient/tdl:PersonSurnameName"/>
          </xdis:PersonSurnameName>
          <xsl:if test="$Patient/tdl:PersonGivenName">
            <xdis:PersonGivenName>
              <xsl:value-of select="$Patient/tdl:PersonGivenName"/>
            </xdis:PersonGivenName>
          </xsl:if>
          <xsl:if test="$Patient/tdl:StreetName">
            <xdis:StreetName>
              <xsl:value-of select="$Patient/tdl:StreetName"/>
            </xdis:StreetName>
          </xsl:if>
          <xsl:if test="$Patient/tdl:DistrictName">
            <xdis:DistrictName>
              <xsl:value-of select="$Patient/tdl:DistrictName"/>
            </xdis:DistrictName>
          </xsl:if>
          <xsl:if test="$Patient/tdl:PostCodeIdentifier">
            <xdis:PostCodeIdentifier>
              <xsl:value-of select="$Patient/tdl:PostCodeIdentifier"/>
            </xdis:PostCodeIdentifier>
          </xsl:if>
          <xdis:EpisodeOfCareStatusCode>inaktiv</xdis:EpisodeOfCareStatusCode>
        </xdis:Patient>
        <xdis:ClinicalInformation>
          <xdis:Text01>
            <xdis:FixedFont>
              <xsl:value-of select="' $Rev: 1883 $ '"/><xdis:Break/>
              Original modtager: <xsl:value-of select="tdl:Roles/tdl:Receiver/PersonGivenName"/><xsl:text> </xsl:text><xsl:value-of select="tdl:Roles/tdl:Receiver/PersonSurnameName"/>, <xsl:value-of select="tdl:Roles/tdl:Receiver/tdl:OrganisationName"/>, <xsl:value-of select="$ReceiverEAN"/>
              <xsl:apply-templates select="tdl:Contents/*"/>
              <xdis:Break/>
              <xsl:text>Underskrift: </xsl:text>
              <xsl:value-of select="$Sender/tdl:Authorisation/tdl:SignedBy"/>
              <xsl:text> d. </xsl:text>
              <xsl:call-template name="formatDateTime">
                <xsl:with-param name="datetime" select="$Sender/tdl:Authorisation/tdl:DateTime"></xsl:with-param>
              </xsl:call-template>
            </xdis:FixedFont>
          </xdis:Text01>
        </xdis:ClinicalInformation>
      </xdis:ClinicalEmail>
    </xdis:Emessage>
  </xsl:template>

  <xsl:template match="tdl:EANIdentifier">
    <xdis:EANIdentifier><xsl:value-of select="."/></xdis:EANIdentifier>
  </xsl:template>
  
  <xsl:template match="tdl:Identifier">
    <xdis:Identifier><xsl:value-of select="."/></xdis:Identifier>
  </xsl:template>
  
  <xsl:template match="tdl:IdentifierCode">
    <xdis:IdentifierCode>
      <xsl:variable name="code" select="text()"/>
      <xsl:choose>
        <xsl:when test="$code = 'sygehusafdelingsnummer'">
          <xsl:value-of select="$code"/>
        </xsl:when>
        <xsl:when test="$code = 'ydernummer'">
          <xsl:text>ydernummer</xsl:text>
        </xsl:when>
        <xsl:when test="$code = 'lokationsnummer'">
          <xsl:text>lokationsnummer</xsl:text>
        </xsl:when>
        <xsl:when test="$code = 'kommunekode'">
          <xsl:text>kommunenummer</xsl:text>
        </xsl:when>
        <xsl:when test="$code = 'amt'">
          <xsl:text>amt</xsl:text>
        </xsl:when>
        <xsl:when test="$code = 'SOR-kode'">
          <xsl:text>sorkode</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>lokationsnummer</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </xdis:IdentifierCode>
  </xsl:template>
  
  <xsl:template match="tdl:OrganisationName">
    <xdis:OrganisationName><xsl:value-of select="."/></xdis:OrganisationName>
  </xsl:template>
  
  <xsl:template match="tdl:DepartmentName">
    <xdis:DepartmentName><xsl:value-of select="."/></xdis:DepartmentName>
  </xsl:template>
  
  <xsl:template match="tdl:UnitName">
    <xdis:UnitName><xsl:value-of select="."/></xdis:UnitName>
  </xsl:template>
  
  <xsl:template match="tdl:StreetName">
    <xdis:StreetName><xsl:value-of select="."/></xdis:StreetName>
  </xsl:template>
  
  <xsl:template match="tdl:SuburbName">
    <xdis:SuburbName><xsl:value-of select="."/></xdis:SuburbName>
  </xsl:template>
  
  <xsl:template match="tdl:PostCodeIdentifier">
    <xsl:if test="../tdl:DistrictName">
      <xdis:DistrictName><xsl:value-of select="../tdl:DistrictName"/></xdis:DistrictName>
    </xsl:if>
    <xdis:PostCodeIdentifier><xsl:value-of select="."/></xdis:PostCodeIdentifier>
  </xsl:template>
  
  <xsl:template match="tdl:DistrictName">
    
  </xsl:template>
  
  <xsl:template match="tdl:PersonTitleIdentifier | tdl:PersonGivenName | tdl:PersonSurnameName | tdl:Authorisation">
  </xsl:template>

  <xsl:template match="mc:CircumstanceRegardingFirstNotice">
    <xdis:Break/>
    <xsl:text>Praktiske oplysninger.</xsl:text>
    <xdis:Break/>
    <xsl:call-template name="multline"/>
    <xdis:Break/>
  </xsl:template>

  <xsl:template match="mc:DateOfFirstPatientContact">
    <xdis:Break/>
    <xsl:text>Dato for første kontakt med kommune/sygehus: </xsl:text>
    <xsl:call-template name="formatDate">
      <xsl:with-param name="date" select="."></xsl:with-param>
    </xsl:call-template>
    <xdis:Break/>
  </xsl:template>

  <!-- Kontakt i kommune -->
  <xsl:template match="mc:MunicipalityContactDepartmentTitle">
    <xdis:Break/>
    <xsl:text>Kontakt i kommunen</xsl:text>
    <xdis:Break/>
    <xsl:value-of select="."/>
    <xsl:text>: </xsl:text>
  </xsl:template>
  <xsl:template match="mc:MunicipalityContactDepartment">
    <xsl:value-of select="."/>
    <xdis:Break/>
  </xsl:template>

  <xsl:template match="mc:MunicipalityContactStreetNameTitle">
    <xsl:value-of select="."/>
    <xsl:text> </xsl:text>
  </xsl:template>
  <xsl:template match="mc:MunicipalityContactStreetName">
    <xsl:value-of select="."/>
    <xdis:Break/>
  </xsl:template>

  <xsl:template match="mc:MunicipalityContactPostCodeIdentifierTitle">
    <xsl:value-of select="."/>
    <xsl:text> </xsl:text>
  </xsl:template>
  <xsl:template match="mc:MunicipalityContactPostCodeIdentifier">
    <xsl:value-of select="."/>
    <xdis:Break/>
  </xsl:template>

  <xsl:template match="mc:MunicipalityContactDistrictNameTitle">
    <xsl:value-of select="."/>
    <xsl:text> </xsl:text>
  </xsl:template>
  <xsl:template match="mc:MunicipalityContactDistrictName">
    <xsl:value-of select="."/>
    <xdis:Break/>
  </xsl:template>

  <xsl:template match="mc:MunicipalityContactTelephoneSubscriberIdentifierTitle">
    <xsl:value-of select="."/>
    <xsl:text> </xsl:text>
  </xsl:template>
  <xsl:template match="mc:MunicipalityContactTelephoneSubscriberIdentifier">
    <xsl:value-of select="."/>
    <xdis:Break/>
  </xsl:template>

  <!-- Kontakt i Regionen -->
  <xsl:template match="mc:CountyContactDepartmentTitle">
    <xdis:Break/>
    <xsl:text>Kontakt i regionen</xsl:text>
    <xdis:Break/>
    <xsl:value-of select="."/>
    <xsl:text>: </xsl:text>
  </xsl:template>
  <xsl:template match="mc:CountyContactDepartment">
    <xsl:value-of select="."/>
    <xdis:Break/>
  </xsl:template>

  <xsl:template match="mc:CountyContactStreetNameTitle">
    <xsl:value-of select="."/>
    <xsl:text> </xsl:text>
  </xsl:template>
  <xsl:template match="mc:CountyContactStreetName">
    <xsl:value-of select="."/>
    <xdis:Break/>
  </xsl:template>

  <xsl:template match="mc:CountyContactPostCodeIdentifierTitle">
    <xsl:value-of select="."/>
    <xsl:text> </xsl:text>
  </xsl:template>
  <xsl:template match="mc:CountyContactPostCodeIdentifier">
    <xsl:value-of select="."/>
    <xdis:Break/>
  </xsl:template>

  <xsl:template match="mc:CountyContactDistrictNameTitle">
    <xsl:value-of select="."/>
    <xsl:text> </xsl:text>
  </xsl:template>
  <xsl:template match="mc:CountyContactDistrictName">
    <xsl:value-of select="."/>
    <xdis:Break/>
  </xsl:template>

  <xsl:template match="mc:CountyContactTelephoneSubscriberIdentifierTitle">
    <xsl:value-of select="."/>
    <xsl:text> </xsl:text>
  </xsl:template>
  <xsl:template match="mc:CountyContactTelephoneSubscriberIdentifier">
    <xsl:value-of select="."/>
    <xdis:Break/>
  </xsl:template>

  <xsl:template match="mc:DateOfDischarge">
    <!-- Ikke muligt da det nu ikke længere er krævet med en udskrivningsdato!  
    <xsl:for-each select="../mc:DateOfAdmission">
    <xdis:Break/>
    <xsl:text>Indlæggelsesdato: </xsl:text>
    <xsl:call-template name="formatDate">
      <xsl:with-param name="date" select="."/>
    </xsl:call-template>
    <xdis:Break/>
    </xsl:for-each>
    -->
    <xdis:Break/>
    <xsl:text>Udskrivningsdato/Ambulatoriedato: </xsl:text>
    <xsl:call-template name="formatDate">
      <xsl:with-param name="date" select="."></xsl:with-param>
    </xsl:call-template>    
    <xdis:Break/>
    <!-- Ikke muligt da det nu ikke længere er krævet med en udskrivningsdato! 
    <xsl:for-each select="../mc:ExerciseType">
      <xdis:Break/>
      <xsl:text>Type af træning: </xsl:text>
      <xsl:apply-templates mode="rehabtype" select="./*"/>
      <xdis:Break/>
    </xsl:for-each>
    <xsl:apply-templates mode="rehabcourse" select="../mc:SpecialRehabilitationExerciseCourse"/>
    -->
  </xsl:template>

  <xsl:template match="mc:DateOfAdmission">
    <xdis:Break/>
    <xsl:text>Indlæggelsesdato: </xsl:text>
    <xsl:call-template name="formatDate">
      <xsl:with-param name="date" select="."/>
    </xsl:call-template>
    <xdis:Break/>
  </xsl:template>

  <xsl:template match="mc:HospitalAmbulatoryControl">
    <xdis:Break/>
    <xsl:text>Ambulant kontrol på sygehus: </xsl:text>
    <xsl:apply-templates mode="AmbulatoryControl" select="./*"/>
    <xdis:Break/>
  </xsl:template>

  <xsl:template mode="AmbulatoryControl" match="mc:HospitalAmbulatoryControlUnknown">
    <xsl:text>Ved ikke</xsl:text>
  </xsl:template>
  <xsl:template mode="AmbulatoryControl" match="mc:HospitalAmbulatoryControlYes">
    <xsl:text>Ja</xsl:text>
  </xsl:template>
  <xsl:template mode="AmbulatoryControl" match="mc:HospitalAmbulatoryControlNo">
    <xsl:text>Nej</xsl:text>
  </xsl:template>

  <!-- Adresse ambulant kontrol -->
  <xsl:template match="mc:AmbulatoryControlDateOfTitle">
    <xsl:if test="$ambctrl">
      <xdis:Break/>
      <xsl:text>Ambulantkontrol informationer:</xsl:text>
      <xdis:Break/>
      <xsl:value-of select="."/>
      <xsl:text> </xsl:text>
    </xsl:if>
  </xsl:template>
  <xsl:template match="mc:AmbulatoryControlDateOf">
    <xsl:if test="$ambctrl">
      <xsl:value-of select="."/>
      <xdis:Break/>
    </xsl:if>
  </xsl:template>

  <xsl:template match="mc:AmbulatoryControlContactEANIdentifierTitle">
    <xsl:if test="$ambctrl">
      <xsl:value-of select="."/>
      <xsl:text> </xsl:text>
    </xsl:if>
  </xsl:template>
  <xsl:template match="mc:AmbulatoryControlContactEANIdentifier">
    <xsl:if test="$ambctrl">
      <xsl:value-of select="."/>
      <xdis:Break/>
    </xsl:if>
  </xsl:template>

  <xsl:template match="mc:AmbulatoryControlContactDepartmentTitle">
    <xsl:if test="$ambctrl">
      <xsl:value-of select="."/>
      <xsl:text> </xsl:text>
    </xsl:if>
  </xsl:template>
  <xsl:template match="mc:AmbulatoryControlContactDepartment">
    <xsl:if test="$ambctrl">
      <xsl:value-of select="."/>
      <xdis:Break/>
    </xsl:if>
  </xsl:template>

  <xsl:template match="mc:AmbulatoryControlContactStreetNameTitle">
    <xsl:if test="$ambctrl">
      <xsl:value-of select="."/>
      <xsl:text> </xsl:text>
    </xsl:if>
  </xsl:template>
  <xsl:template match="mc:AmbulatoryControlContactStreetName">
    <xsl:if test="$ambctrl">
      <xsl:value-of select="."/>
      <xdis:Break/>
    </xsl:if>
  </xsl:template>

  <xsl:template match="mc:AmbulatoryControlContactPostCodeIdentifierTitle">
    <xsl:if test="$ambctrl">
      <xsl:value-of select="."/>
      <xsl:text> </xsl:text>
    </xsl:if>
  </xsl:template>
  <xsl:template match="mc:AmbulatoryControlContactPostCodeIdentifier">
    <xsl:if test="$ambctrl">
      <xsl:value-of select="."/>
      <xdis:Break/>
    </xsl:if>
  </xsl:template>

  <xsl:template match="mc:AmbulatoryControlContactDistrictNameTitle">
    <xsl:if test="$ambctrl">
      <xsl:value-of select="."/>
      <xsl:text> </xsl:text>
    </xsl:if>
  </xsl:template>
  <xsl:template match="mc:AmbulatoryControlContactDistrictName">
    <xsl:if test="$ambctrl">
      <xsl:value-of select="."/>
      <xdis:Break/>
    </xsl:if>
  </xsl:template>

  <xsl:template match="mc:AmbulatoryControlContactTelephoneSubscriberIdentifierTitle">
    <xsl:if test="$ambctrl">
      <xsl:value-of select="."/>
      <xsl:text> </xsl:text>
    </xsl:if>
  </xsl:template>
  <xsl:template match="mc:AmbulatoryControlContactTelephoneSubscriberIdentifier">
    <xsl:if test="$ambctrl">
      <xsl:value-of select="."/>
      <xdis:Break/>
    </xsl:if>
  </xsl:template>

  <!-- Henv. diagnoser -->
  <xsl:template match="mc:GOPReferenceDiagnosePrimaryICD10Title">
    <xdis:Break/>
    <xsl:text>Henvisningsdiagnose for genoptræningsforløb</xsl:text>
    <xdis:Break/>
    <xsl:call-template name="format">
      <xsl:with-param name="str" select="."/>
      <xsl:with-param name="size" select="18"/>
    </xsl:call-template>
  </xsl:template>
  <xsl:template match="mc:GOPReferenceDiagnosePrimaryCodeMeaningTitle">
    <xsl:value-of select="."/>
    <xdis:Break/>
  </xsl:template>
  <xsl:template match="mc:GOPReferenceDiagnosePrimaryICD10">
    <xsl:call-template name="format">
      <xsl:with-param name="str" select="."/>
      <xsl:with-param name="size" select="18"></xsl:with-param>
    </xsl:call-template>
  </xsl:template>
  <xsl:template match="mc:GOPReferenceDiagnosePrimaryCodeMeaning">
    <xsl:call-template name="formatend">
      <xsl:with-param name="offset" select="18"/>
      <xsl:with-param name="str" select="string(.)"/>
    </xsl:call-template>
  </xsl:template>

  <!-- Henv. diagnoser -->
  <xsl:template match="mc:GOPReferenceDiagnoseSecondaryICD10Title">
    <xdis:Break/>
    <xsl:text>Sekundære diagnoser SKS ICD10</xsl:text>
    <xdis:Break/>
    <xsl:call-template name="format">
      <xsl:with-param name="str" select="."/>
      <xsl:with-param name="size" select="18"/>
    </xsl:call-template>
  </xsl:template>
  <xsl:template match="mc:GOPReferenceDiagnoseSecondaryCodeMeaningTitle">
    <xsl:call-template name="formatend">
      <xsl:with-param name="offset" select="18"/>
      <xsl:with-param name="str" select="string(.)"/>
    </xsl:call-template>
  </xsl:template>
  <xsl:template match="mc:GOPReferenceDiagnoseSecondaryICD10_1">
    <xsl:call-template name="format">
      <xsl:with-param name="str" select="."/>
      <xsl:with-param name="size" select="18"/>
    </xsl:call-template>
  </xsl:template>
  <xsl:template match="mc:GOPReferenceDiagnoseSecondaryCodeMeaning_1">
    <xsl:call-template name="formatend">
      <xsl:with-param name="offset" select="18"/>
      <xsl:with-param name="str" select="string(.)"/>
    </xsl:call-template>
  </xsl:template>
  <xsl:template match="mc:GOPReferenceDiagnoseSecondaryICD10_2">
    <xsl:call-template name="format">
      <xsl:with-param name="str" select="."/>
      <xsl:with-param name="size" select="18"/>
    </xsl:call-template>
  </xsl:template>
  <xsl:template match="mc:GOPReferenceDiagnoseSecondaryCodeMeaning_2">
    <xsl:call-template name="formatend">
      <xsl:with-param name="offset" select="18"/>
      <xsl:with-param name="str" select="string(.)"/>
    </xsl:call-template>
  </xsl:template>
  <xsl:template match="mc:GOPReferenceDiagnoseSecondaryICD10_3">
    <xsl:call-template name="format">
      <xsl:with-param name="str" select="."/>
      <xsl:with-param name="size" select="18"/>
    </xsl:call-template>
  </xsl:template>
  <xsl:template match="mc:GOPReferenceDiagnoseSecondaryCodeMeaning_3">
    <xsl:call-template name="formatend">
      <xsl:with-param name="offset" select="18"/>
      <xsl:with-param name="str" select="string(.)"/>
    </xsl:call-template>
  </xsl:template>
  <xsl:template match="mc:GOPReferenceDiagnoseSecondaryICD10_4">
    <xsl:call-template name="format">
      <xsl:with-param name="str" select="."/>
      <xsl:with-param name="size" select="18"/>
    </xsl:call-template>
  </xsl:template>
  <xsl:template match="mc:GOPReferenceDiagnoseSecondaryCodeMeaning_4">
    <xsl:call-template name="formatend">
      <xsl:with-param name="offset" select="18"/>
      <xsl:with-param name="str" select="string(.)"/>
    </xsl:call-template>
  </xsl:template>
  <xsl:template match="mc:GOPReferenceDiagnoseSecondaryICD10_5">
    <xsl:call-template name="format">
      <xsl:with-param name="str" select="."/>
      <xsl:with-param name="size" select="18"/>
    </xsl:call-template>
  </xsl:template>
  <xsl:template match="mc:GOPReferenceDiagnoseSecondaryCodeMeaning_5">
    <xsl:call-template name="formatend">
      <xsl:with-param name="offset" select="18"/>
      <xsl:with-param name="str" select="string(.)"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="mc:AdditionalClinicalInformation">
    <xdis:Break/>
    <xsl:text>Supplerende kliniske oplysninger</xsl:text>
    <xdis:Break/>
    <xsl:call-template name="multline"/>
    <xdis:Break/>
  </xsl:template>


  <xsl:template match="mc:ExerciseType">
    <xdis:Break/>
    <xsl:text>Type af træning: </xsl:text>
    <xsl:apply-templates mode="rehabtype" select="./*"/>
    <xdis:Break/>
  </xsl:template>

  <xsl:template mode="rehabtype" match="mc:RehabilitationExercise">
    <xsl:text>Genoptræning</xsl:text>
  </xsl:template>
  <xsl:template mode="rehabtype" match="mc:SpecialRehabilitationExercise">
    <xsl:text>Specialiseret genoptræning</xsl:text>
  </xsl:template>
  <xsl:template mode="rehabtype" match="mc:HospitalGuidedSelfExercise">
    <xsl:text>Egentræning efter instruks fra sygehus</xsl:text>
  </xsl:template>

  <xsl:template match="mc:SpecialRehabilitationExerciseCourse">
   <xsl:if test="$specialrehab">
      <xsl:text>Årsag til specialiseret træning: </xsl:text>
      <xsl:if test="./mc:MultiDisciplinaryCollaboration">
        <xsl:text>tværfagligt samarbejde på speciallægeniveau</xsl:text>
      </xsl:if>
      <xsl:if test="./mc:PatientSafety">
        <xsl:if test="./mc:MultiDisciplinaryCollaboration">
          <xsl:text> og </xsl:text>
        </xsl:if>
        <xsl:text>patientsikkerhed</xsl:text>
      </xsl:if>
      <xsl:text>.</xsl:text>
      <xdis:Break/>
    </xsl:if>
  </xsl:template>


  <xsl:template match="mc:FinalResult">
    <xdis:Break/>
    <xsl:text>Behov for slutstatus: </xsl:text>
    <xsl:choose>
      <xsl:when test="string(.)='0'">
        <xsl:text>Nej</xsl:text>
      </xsl:when>
      <xsl:otherwise>Ja</xsl:otherwise>
    </xsl:choose>
      <xdis:Break/>
  </xsl:template>

  <!-- Test resultater -->
  <xsl:template match="mc:AbilityTestTitle">
    <xdis:Break/>
    <xsl:text>Funktionsevnemålinger:</xsl:text>
    <xdis:Break/>
    <xsl:call-template name="format">
      <xsl:with-param name="str" select="'Dato/Navn'"/>
      <xsl:with-param name="size" select="11"/>
    </xsl:call-template>
    <xsl:for-each select="following-sibling::*[starts-with(local-name(),'AbilityTestName')]">
      <xsl:call-template name="format">
        <xsl:with-param name="str" select="string(.)"/>
      </xsl:call-template>
    </xsl:for-each>
    <xdis:Break/>
    
    <xsl:for-each select="../mc:*[starts-with(local-name(),'AbilityDate') and string-length(local-name()) &lt;= 12] ">
    <xsl:variable name="name" select="local-name()"/>
    <xsl:call-template name="format">
      <xsl:with-param name="str">
        <xsl:call-template name="formatDate">
          <xsl:with-param name="date" select="string(.)"/>
        </xsl:call-template>
      </xsl:with-param>
      <xsl:with-param name="size" select="11"/>
    </xsl:call-template>
    <xsl:for-each select="following-sibling::*[starts-with(local-name(), $name) and contains(local-name(), 'Result')]">
      <xsl:call-template name="format">
        <xsl:with-param name="str" select="string(.)"/>
      </xsl:call-template>
    </xsl:for-each>
    <xdis:Break/>
    </xsl:for-each>
  </xsl:template>
  
  <xsl:template match="node()[starts-with(local-name(),'AbilityDate') or starts-with(local-name(),'AbilityTestName')]">
    <!-- Eat left overs -->
  </xsl:template>
  
  <xsl:template match="mc:AdditionalAbilityMeasureComments">
    <xdis:Break/>
    <xsl:text>Supplerende funktionsevnemålinger / kommentarer</xsl:text>
    <xdis:Break/>
    <xsl:call-template name="multline"/>
    <xdis:Break/>
  </xsl:template>

  <xsl:template match="mc:AbilityBeforeDisease">
    <xdis:Break/>
    <xsl:text>Funktionsevne før sygdom:</xsl:text>
    <xdis:Break/>
    <xsl:call-template name="multline"/>
    <xdis:Break/>
  </xsl:template>

  <!-- Indsats under indlæggelse  -->
  <xsl:template match="mc:EffortsDuringHospitalizationDateTitle">
    <xdis:Break/>
    <xsl:text>Indsats under indlæggelse:</xsl:text>
    <xdis:Break/>
    <xsl:call-template name="format">
      <xsl:with-param name="str" select="."/>
      <xsl:with-param name="size" select="11"/>
    </xsl:call-template>
  </xsl:template>
  
  <xsl:template match="mc:EffortsDuringHospitalizationSKSTitle">
    <xsl:call-template name="format">
      <xsl:with-param name="str" select="."/>
      <xsl:with-param name="size" select="18"/>
    </xsl:call-template>
  </xsl:template>
  
  <xsl:template match="mc:EffortsDuringHospitalizationDescrTitle">
    <xsl:call-template name="formatend">
      <xsl:with-param name="str" select="string(.)"/>
      <xsl:with-param name="offset" select="18"/>
    </xsl:call-template>
  </xsl:template>
  
  <xsl:template match="mc:*[contains(local-name(), 'EffortsDuringHospitalizationDate_')]">
    <xsl:call-template name="format">
      <xsl:with-param name="str" select="."/>
      <xsl:with-param name="size" select="11"/>
    </xsl:call-template>
  </xsl:template>
  
  
  <xsl:template match="mc:*[contains(local-name(), 'EffortsDuringHospitalizationSKS_')]">
    <xsl:call-template name="format">
      <xsl:with-param name="str" select="."/>
      <xsl:with-param name="size" select="18"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="mc:*[contains(local-name(), 'EffortsDuringHospitalizationDescr_')]">
    <xsl:call-template name="format">
      <xsl:with-param name="str" select="."/>
      <xsl:with-param name="size" select="18"/>
    </xsl:call-template><xdis:Break/>
  </xsl:template>

  <xsl:template match="mc:EffortsDuringHospitalizationAdditionalInformation">
    <xdis:Break/>
    <xsl:text>Supplerende oplysninger vedr. indsats under indlæggelse:</xsl:text>
    <xdis:Break/>
    <xsl:call-template name="multline"/>
    <xdis:Break/>
  </xsl:template>

  <xsl:template match="mc:AbilityAtDischargeDescription">
    <xdis:Break/>
    <xsl:text>Aktuel funktionsevne på udskrivningstidspunkt:</xsl:text>
    <xdis:Break/>
    <xsl:call-template name="multline"/>
    <xdis:Break/>
  </xsl:template>

  <xsl:template match="mc:RehabilitationRequiredAtDischargeDescription">
    <xdis:Break/>
    <xsl:text>Genoptræningsbehov ved udskrivning:</xsl:text>
    <xdis:Break/>
    <xsl:call-template name="multline"/>
    <xdis:Break/>
  </xsl:template>

  <xsl:template match="mc:AuxiliariesPassedByHospital">
    <xdis:Break/>
    <xsl:text>Hjælpemidler udleveret af hospitalet:</xsl:text>
    <xdis:Break/>
    <xsl:call-template name="multline"/>
    <xdis:Break/>
  </xsl:template>
  
<!-- 
  <xsl:template match="mc:AuxiliariesPassedByHospitalWheelChair">
    <xdis:Space/><xdis:Space/>Kørestol<xdis:Break/>
  </xsl:template>
  
  <xsl:template match="mc:AuxiliariesPassedByHospitalZimmerFrame">
    <xdis:Space/><xdis:Space/>Rollator<xdis:Break/>
  </xsl:template>
  
  <xsl:template match="mc:AuxiliariesPassedByHospitalCane">
    <xdis:Space/><xdis:Space/>Stokke<xdis:Break/>
  </xsl:template>
  
  <xsl:template match="mc:AuxiliariesPassedByHospitalWalkingFrame">
    <xdis:Space/><xdis:Space/>Gangstativ<xdis:Break/>
  </xsl:template>
  
  <xsl:template match="mc:AuxiliariesPassedByHospitalChair">
    <xdis:Space/><xdis:Space/>Badestol<xdis:Break/>
  </xsl:template>
  
  <xsl:template match="mc:AuxiliariesPassedByHospitalToiletRaiser">
    <xdis:Space/><xdis:Space/>Toilet forhøjer<xdis:Break/>
  </xsl:template>
  
  <xsl:template match="mc:AuxiliariesPassedByHospitalBedBlocks">
    <xdis:Space/><xdis:Space/>Sengeklodser / forhøjer<xdis:Break/>
  </xsl:template>
  
  <xsl:template match="mc:AuxiliariesPassedByHospitalOther">
    <xsl:call-template name="multline"/>
    <xdis:Break/>
  </xsl:template>
-->
  
  <xsl:template match="mc:AdditionalInformation">
    <xdis:Break/>
    <xsl:text>Supplerende oplysninger:</xsl:text>
    <xdis:Break/>
    <xsl:call-template name="multline"/>
    <xdis:Break/>
  </xsl:template>

  <xsl:template name="format">
    <xsl:param name="str"/>
    <xsl:param name="size" select="12"/>
    <xsl:value-of select="$str"/>
    <xsl:call-template name="spacegenerator">
      <xsl:with-param name="spaces" select="($size - string-length($str))"/>
    </xsl:call-template>
  </xsl:template>

<xsl:template name="formatDateTime">
  <xsl:param name="datetime" select="'2007-04-25T00:00:00'"/>
  <xsl:call-template name="formatDate">
    <xsl:with-param name="date" select="substring-before($datetime,'T')"/>
  </xsl:call-template>
  <xsl:text> Kl: </xsl:text>
  <xsl:value-of select="substring-after($datetime, 'T')"/>
</xsl:template>

<xsl:template name="formatDate">
  <xsl:param name="date" select="'1210-12-24'"/>
  <xsl:variable name="year" select="substring($date,1,4)"/>
  <xsl:variable name="month" select="substring($date, 6, 2)"/>
  <xsl:variable name="day" select="substring($date, 9, 2)"/>
  <xsl:value-of select="$day"/>-<xsl:value-of select="$month"/>-<xsl:value-of select="$year"/>
</xsl:template>

  <xsl:template name="formatend">
    <xsl:param name="str"/>
    <xsl:param name="size" select="12"/>
    <xsl:param name="offset" select="0"/>
    <xsl:choose>
      <xsl:when test="(string-length($str)+$offset)>70">
        <xsl:value-of select="substring($str, 0, 69 - $offset)"/>-
        <xdis:Break/>
        <xsl:call-template name="spacegenerator">
          <xsl:with-param name="spaces" select="$offset"/>
        </xsl:call-template>
        <xsl:call-template name="formatend">
          <xsl:with-param name="offset" select="$offset"/>
          <xsl:with-param name="size" select="$size"/>
          <xsl:with-param name="str" select="substring($str, 69-$offset)"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$str"/>
        <xdis:Break/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="spacegenerator">
    <xsl:param name="spaces"/>
    <xsl:if test="$spaces > 0">
      <xdis:Space/>
      <xsl:call-template name="spacegenerator">
        <xsl:with-param name="spaces" select="$spaces - 1"/>
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <xsl:template name="multline">
    <xsl:apply-templates select="text() | *"/>
  </xsl:template>
  
  <xsl:template match="text()">
    <xsl:value-of select="."/>
  </xsl:template>
  
  <xsl:template match="cm:br">
    <xdis:Break/>
  </xsl:template>
  
  <xsl:template match="cm:b">
    <xsl:apply-templates select="text() | *"/>
  </xsl:template>
  
  <xsl:template name="cutTo14">
    <xsl:param name="id"/>
    <xsl:variable name="length" select="string-length($id)"/>
    <xsl:choose>
      <xsl:when test="length &gt; 14"><xsl:value-of select="substring($id, $length - 14)"/></xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$id"/>
      </xsl:otherwise>
    </xsl:choose>    
  </xsl:template>
  
  <xsl:template match="*">
    <xdis:Break/>Unmatched: <xsl:value-of select="local-name()"/><xdis:Break/>
    Value: <xsl:value-of select="."/><xdis:Break/>
  </xsl:template>
   
</xsl:stylesheet>
